polyA package
=============

Submodules
----------

polyA.alignment module
----------------------

.. automodule:: polyA.alignment
   :members:
   :undoc-members:
   :show-inheritance:

polyA.calc\_repeat\_scores module
---------------------------------

.. automodule:: polyA.calc_repeat_scores
   :members:
   :undoc-members:
   :show-inheritance:

polyA.calculate\_score module
-----------------------------

.. automodule:: polyA.calculate_score
   :members:
   :undoc-members:
   :show-inheritance:

polyA.collapse\_matrices module
-------------------------------

.. automodule:: polyA.collapse_matrices
   :members:
   :undoc-members:
   :show-inheritance:

polyA.confidence\_cm module
---------------------------

.. automodule:: polyA.confidence_cm
   :members:
   :undoc-members:
   :show-inheritance:

polyA.constants module
----------------------

.. automodule:: polyA.constants
   :members:
   :undoc-members:
   :show-inheritance:

polyA.edges module
------------------

.. automodule:: polyA.edges
   :members:
   :undoc-members:
   :show-inheritance:

polyA.extract\_nodes module
---------------------------

.. automodule:: polyA.extract_nodes
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_align\_matrix module
--------------------------------

.. automodule:: polyA.fill_align_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_confidence\_matrix module
-------------------------------------

.. automodule:: polyA.fill_confidence_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_consensus\_position\_matrix module
----------------------------------------------

.. automodule:: polyA.fill_consensus_position_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_node\_confidence module
-----------------------------------

.. automodule:: polyA.fill_node_confidence
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_path\_graph module
------------------------------

.. automodule:: polyA.fill_path_graph
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_probability\_matrix module
--------------------------------------

.. automodule:: polyA.fill_probability_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.fill\_support\_matrix module
----------------------------------

.. automodule:: polyA.fill_support_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.get\_path module
----------------------

.. automodule:: polyA.get_path
   :members:
   :undoc-members:
   :show-inheritance:

polyA.lambda\_provider module
-----------------------------

.. automodule:: polyA.lambda_provider
   :members:
   :undoc-members:
   :show-inheritance:

polyA.load\_alignments module
-----------------------------

.. automodule:: polyA.load_alignments
   :members:
   :undoc-members:
   :show-inheritance:

polyA.matrices module
---------------------

.. automodule:: polyA.matrices
   :members:
   :undoc-members:
   :show-inheritance:

polyA.output module
-------------------

.. automodule:: polyA.output
   :members:
   :undoc-members:
   :show-inheritance:

polyA.pad\_sequences module
---------------------------

.. automodule:: polyA.pad_sequences
   :members:
   :undoc-members:
   :show-inheritance:

polyA.performance module
------------------------

.. automodule:: polyA.performance
   :members:
   :undoc-members:
   :show-inheritance:

polyA.print\_helpers module
---------------------------

.. automodule:: polyA.print_helpers
   :members:
   :undoc-members:
   :show-inheritance:

polyA.printers module
---------------------

.. automodule:: polyA.printers
   :members:
   :undoc-members:
   :show-inheritance:

polyA.prior\_counts module
--------------------------

.. automodule:: polyA.prior_counts
   :members:
   :undoc-members:
   :show-inheritance:

polyA.substitution\_matrix module
---------------------------------

.. automodule:: polyA.substitution_matrix
   :members:
   :undoc-members:
   :show-inheritance:

polyA.sum\_repeat\_scores module
--------------------------------

.. automodule:: polyA.sum_repeat_scores
   :members:
   :undoc-members:
   :show-inheritance:

polyA.ultra\_provider module
----------------------------

.. automodule:: polyA.ultra_provider
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: polyA
   :members:
   :undoc-members:
   :show-inheritance:
